@@ -40,12 +40,13 @@ class Cloud_Connect_AWS:
         is a valid token provided by the Falcon API SDK OAuth2 class.
     """
 
-    def __init__(self, access_token, base_url="https://api.crowdstrike.com"):
+    def __init__(self, access_token, base_url="https://api.crowdstrike.com", ssl_verify=True):
         """ Instantiates the base class, ingests the authorization token, 
             and initializes the headers and base_url global variables. 
         """
         self.headers = {'Authorization': 'Bearer {}'.format(access_token)}
         self.base_url = base_url
+        self.ssl_verify = ssl_verify
 
     class Result:
         """ Subclass to handle parsing of result client output. """
@@ -70,7 +71,7 @@ class Cloud_Connect_AWS:
         HEADERS = self.headers
         PARAMS = parameters
         try:
-            response = requests.request("GET", FULL_URL, params=PARAMS, headers=HEADERS, verify=False)
+            response = requests.request("GET", FULL_URL, params=PARAMS, headers=HEADERS, verify=self.ssl_verify)
             returned = self.Result()(response.status_code, response.headers, response.json())
         except Exception as e:
             returned = self.Result()(500, {}, str(e))
@@ -83,7 +84,7 @@ class Cloud_Connect_AWS:
         FULL_URL = self.base_url+'/cloud-connect-aws/combined/settings/v1'
         HEADERS = self.headers
         try:
-            response = requests.request("GET", FULL_URL, headers=HEADERS, verify=False)
+            response = requests.request("GET", FULL_URL, headers=HEADERS, verify=self.ssl_verify)
             returned = self.Result()(response.status_code, response.headers, response.json())
         except Exception as e:
             returned = self.Result()(500, {}, str(e))
@@ -97,7 +98,7 @@ class Cloud_Connect_AWS:
         FULL_URL = self.base_url+'/cloud-connect-aws/entities/accounts/v1?ids={}'.format(ID_LIST)
         HEADERS = self.headers
         try:
-            response = requests.request("GET", FULL_URL, headers=HEADERS, verify=False)
+            response = requests.request("GET", FULL_URL, headers=HEADERS, verify=self.ssl_verify)
             returned = self.Result()(response.status_code, response.headers, response.json())
         except Exception as e:
             returned = self.Result()(500, {}, str(e))
@@ -111,7 +112,7 @@ class Cloud_Connect_AWS:
         PARAMS=parameters
         BODY=body
         try:
-            response = requests.request("POST", FULL_URL, params=PARAMS, json=BODY, headers=self.headers, verify=False)
+            response = requests.request("POST", FULL_URL, params=PARAMS, json=BODY, headers=self.headers, verify=self.ssl_verify)
             returned = self.Result()(response.status_code, response.headers, response.json())
         except Exception as e:
             returned = self.Result()(500, {}, str(e))
@@ -124,7 +125,7 @@ class Cloud_Connect_AWS:
         ID_LIST = str(ids).replace(",","&ids=")
         FULL_URL = self.base_url+'/cloud-connect-aws/entities/accounts/v1?ids={}'.format(ID_LIST)
         try:
-            response = requests.request("DELETE", FULL_URL, headers=self.headers, verify=False)
+            response = requests.request("DELETE", FULL_URL, headers=self.headers, verify=self.ssl_verify)
             returned = self.Result()(response.status_code, response.headers, response.json())
         except Exception as e:
             returned = self.Result()(500, {}, str(e))
@@ -137,7 +138,7 @@ class Cloud_Connect_AWS:
         FULL_URL = self.base_url+'/cloud-connect-aws/entities/accounts/v1'
         BODY=body
         try:
-            response = requests.request("PATCH", FULL_URL, json=BODY, headers=self.headers, verify=False)
+            response = requests.request("PATCH", FULL_URL, json=BODY, headers=self.headers, verify=self.ssl_verify)
             returned = self.Result()(response.status_code, response.headers, response.json())
         except Exception as e:
             returned = self.Result()(500, {}, str(e))
@@ -151,7 +152,7 @@ class Cloud_Connect_AWS:
         HEADERS = self.headers
         BODY = body
         try:
-            response = requests.request("POST", FULL_URL, json=BODY, headers=HEADERS, verify=False)
+            response = requests.request("POST", FULL_URL, json=BODY, headers=HEADERS, verify=self.ssl_verify)
             returned = self.Result()(response.status_code, response.headers, response.json())
         except Exception as e:
             returned = self.Result()(500, {}, str(e))
@@ -166,7 +167,7 @@ class Cloud_Connect_AWS:
         HEADERS = self.headers
         BODY=body
         try:
-            response = requests.request("POST", FULL_URL, json=BODY, headers=HEADERS, verify=False)
+            response = requests.request("POST", FULL_URL, json=BODY, headers=HEADERS, verify=self.ssl_verify)
             returned = self.Result()(response.status_code, response.headers, response.json())
         except Exception as e:
             returned = self.Result()(500, {}, str(e))
@@ -182,7 +183,7 @@ class Cloud_Connect_AWS:
         HEADERS = self.headers
         PARAMS = parameters
         try:
-            response = requests.request("GET", FULL_URL, params=PARAMS, headers=HEADERS, verify=False)
+            response = requests.request("GET", FULL_URL, params=PARAMS, headers=HEADERS, verify=self.ssl_verify)
             returned = self.Result()(response.status_code, response.headers, response.json())
         except Exception as e:
             returned = self.Result()(500, {}, str(e))
