@@ -40,12 +40,13 @@ class Firewall_Policies:
         is a valid token provided by the Falcon API SDK OAuth2 class.
     """
 
-    def __init__(self, access_token, base_url='https://api.crowdstrike.com'):
+    def __init__(self, access_token, base_url='https://api.crowdstrike.com', ssl_verify=True):
         """ Instantiates the base class, ingests the authorization token, 
             and initializes the headers and base_url global variables. 
         """
         self.headers = { 'Authorization': 'Bearer {}'.format(access_token) }
         self.base_url = base_url
+        self.ssl_verify = ssl_verify
 
     class Result:
         """ Subclass to handle parsing of result client output. """
@@ -70,7 +71,7 @@ class Firewall_Policies:
         HEADERS = self.headers
         PARAMS = parameters
         try:
-            response = requests.request("GET", FULL_URL, params=PARAMS, headers=HEADERS, verify=False)
+            response = requests.request("GET", FULL_URL, params=PARAMS, headers=HEADERS, verify=self.ssl_verify)
             returned = self.Result()(response.status_code, response.headers, response.json())
         except Exception as e:
             returned = self.Result()(500, {}, str(e))
@@ -86,7 +87,7 @@ class Firewall_Policies:
         HEADERS = self.headers
         PARAMS = parameters
         try:
-            response = requests.request("GET", FULL_URL, params=PARAMS, headers=HEADERS, verify=False)
+            response = requests.request("GET", FULL_URL, params=PARAMS, headers=HEADERS, verify=self.ssl_verify)
             returned = self.Result()(response.status_code, response.headers, response.json())
         except Exception as e:
             returned = self.Result()(500, {}, str(e))
@@ -101,7 +102,7 @@ class Firewall_Policies:
         BODY = body
         PARAMS = parameters
         try:
-            response = requests.request("POST", FULL_URL, params=PARAMS, json=BODY, headers=HEADERS, verify=False)
+            response = requests.request("POST", FULL_URL, params=PARAMS, json=BODY, headers=HEADERS, verify=self.ssl_verify)
             returned = self.Result()(response.status_code, response.headers, response.json())
         except Exception as e:
             returned = self.Result()(500, {}, str(e))
@@ -118,7 +119,7 @@ class Firewall_Policies:
         HEADERS = self.headers
         BODY = body
         try:
-            response = requests.request("POST", FULL_URL, json=BODY, headers=HEADERS, verify=False)
+            response = requests.request("POST", FULL_URL, json=BODY, headers=HEADERS, verify=self.ssl_verify)
             returned = self.Result()(response.status_code, response.headers, response.json())
         except Exception as e:
             returned = self.Result()(500, {}, str(e))
@@ -132,7 +133,7 @@ class Firewall_Policies:
         FULL_URL = self.base_url+'/policy/entities/firewall/v1?ids={}'.format(ID_LIST)
         HEADERS = self.headers
         try:
-            response = requests.request("GET", FULL_URL, headers=HEADERS, verify=False)
+            response = requests.request("GET", FULL_URL, headers=HEADERS, verify=self.ssl_verify)
             returned = self.Result()(response.status_code, response.headers, response.json())
         except Exception as e:
             returned = self.Result()(500, {}, str(e))
@@ -147,7 +148,7 @@ class Firewall_Policies:
         PARAMS = parameters
         BODY = body
         try:
-            response = requests.request("POST", FULL_URL, params=PARAMS, json=BODY, headers=HEADERS, verify=False)
+            response = requests.request("POST", FULL_URL, params=PARAMS, json=BODY, headers=HEADERS, verify=self.ssl_verify)
             returned = self.Result()(response.status_code, response.headers, response.json())
         except Exception as e:
             returned = self.Result()(500, {}, str(e))
@@ -161,7 +162,7 @@ class Firewall_Policies:
         FULL_URL = self.base_url+'/policy/entities/firewall/v1?ids={}'.format(ID_LIST)
         HEADERS = self.headers
         try:
-            response = requests.request("DELETE", FULL_URL, headers=HEADERS, verify=False)
+            response = requests.request("DELETE", FULL_URL, headers=HEADERS, verify=self.ssl_verify)
             returned = self.Result()(response.status_code, response.headers, response.json())
         except Exception as e:
             returned = self.Result()(500, {}, str(e))
@@ -175,7 +176,7 @@ class Firewall_Policies:
         HEADERS = self.headers
         BODY = body
         try:
-            response = requests.request("PATCH", FULL_URL, json=BODY, headers=HEADERS, verify=False)
+            response = requests.request("PATCH", FULL_URL, json=BODY, headers=HEADERS, verify=self.ssl_verify)
             returned = self.Result()(response.status_code, response.headers, response.json())
         except Exception as e:
             returned = self.Result()(500, {}, str(e))
@@ -191,7 +192,7 @@ class Firewall_Policies:
         HEADERS = self.headers
         PARAMS = parameters
         try:
-            response = requests.request("GET", FULL_URL, params=PARAMS, headers=HEADERS, verify=False)
+            response = requests.request("GET", FULL_URL, params=PARAMS, headers=HEADERS, verify=self.ssl_verify)
             returned = self.Result()(response.status_code, response.headers, response.json())
         except Exception as e:
             returned = self.Result()(500, {}, str(e))
@@ -207,7 +208,7 @@ class Firewall_Policies:
         HEADERS = self.headers
         PARAMS = parameters
         try:
-            response = requests.request("GET", FULL_URL, params=PARAMS, headers=HEADERS, verify=False)
+            response = requests.request("GET", FULL_URL, params=PARAMS, headers=HEADERS, verify=self.ssl_verify)
             returned = self.Result()(response.status_code, response.headers, response.json())
         except Exception as e:
             returned = self.Result()(500, {}, str(e))
