@@ -40,12 +40,13 @@ class Iocs:
         is a valid token provided by the Falcon API SDK OAuth2 class.
     """
 
-    def __init__(self, access_token, base_url='https://api.crowdstrike.com'):
+    def __init__(self, access_token, base_url='https://api.crowdstrike.com', ssl_verify=True):
         """ Instantiates the base class, ingests the authorization token, 
             and initializes the headers and base_url global variables. 
         """
         self.headers = { 'Authorization': 'Bearer {}'.format(access_token) }
         self.base_url = base_url
+        self.ssl_verify = ssl_verify
 
     class Result:
         """ Subclass to handle parsing of result client output. """
@@ -68,7 +69,7 @@ class Iocs:
         HEADERS = self.headers
         PARAMS = parameters
         try:
-            response = requests.request("GET", FULL_URL, params=PARAMS, headers=HEADERS, verify=False)
+            response = requests.request("GET", FULL_URL, params=PARAMS, headers=HEADERS, verify=self.ssl_verify)
             returned = self.Result()(response.status_code, response.headers, response.json())
         except Exception as e:
             returned = self.Result()(500, {}, str(e))
@@ -82,7 +83,7 @@ class Iocs:
         HEADERS = self.headers
         PARAMS = parameters
         try:
-            response = requests.request("GET", FULL_URL, params=PARAMS, headers=HEADERS, verify=False)
+            response = requests.request("GET", FULL_URL, params=PARAMS, headers=HEADERS, verify=self.ssl_verify)
             returned = self.Result()(response.status_code, response.headers, response.json())
         except Exception as e:
             returned = self.Result()(500, {}, str(e))
@@ -96,7 +97,7 @@ class Iocs:
         HEADERS = self.headers
         BODY = body
         try:
-            response = requests.request("POST", FULL_URL, json=BODY, headers=HEADERS, verify=False)
+            response = requests.request("POST", FULL_URL, json=BODY, headers=HEADERS, verify=self.ssl_verify)
             returned = self.Result()(response.status_code, response.headers, response.json())
         except Exception as e:
             returned = self.Result()(500, {}, str(e))
@@ -110,7 +111,7 @@ class Iocs:
         HEADERS = self.headers
         PARAMS = parameters
         try:
-            response = requests.request("DELETE", FULL_URL, params=PARAMS, headers=HEADERS, verify=False)
+            response = requests.request("DELETE", FULL_URL, params=PARAMS, headers=HEADERS, verify=self.ssl_verify)
             returned = self.Result()(response.status_code, response.headers, response.json())
         except Exception as e:
             returned = self.Result()(500, {}, str(e))
@@ -125,7 +126,7 @@ class Iocs:
         PARAMS = parameters
         BODY = body
         try:
-            response = requests.request("PATCH", FULL_URL, params=PARAMS, json=BODY, headers=HEADERS, verify=False)
+            response = requests.request("PATCH", FULL_URL, params=PARAMS, json=BODY, headers=HEADERS, verify=self.ssl_verify)
             returned = self.Result()(response.status_code, response.headers, response.json())
         except Exception as e:
             returned = self.Result()(500, {}, str(e))
@@ -139,7 +140,7 @@ class Iocs:
         HEADERS = self.headers
         PARAMS = parameters
         try:
-            response = requests.request("GET", FULL_URL, params=PARAMS, headers=HEADERS, verify=False)
+            response = requests.request("GET", FULL_URL, params=PARAMS, headers=HEADERS, verify=self.ssl_verify)
             returned = self.Result()(response.status_code, response.headers, response.json())
         except Exception as e:
             returned = self.Result()(500, {}, str(e))
@@ -153,7 +154,7 @@ class Iocs:
         HEADERS = self.headers
         PARAMS = parameters
         try:
-            response = requests.request("GET", FULL_URL, params=PARAMS, headers=HEADERS, verify=False)
+            response = requests.request("GET", FULL_URL, params=PARAMS, headers=HEADERS, verify=self.ssl_verify)
             returned = self.Result()(response.status_code, response.headers, response.json())
         except Exception as e:
             returned = self.Result()(500, {}, str(e))
@@ -167,7 +168,7 @@ class Iocs:
         HEADERS = self.headers
         PARAMS = parameters
         try:
-            response = requests.request("GET", FULL_URL, params=PARAMS, headers=HEADERS, verify=False)
+            response = requests.request("GET", FULL_URL, params=PARAMS, headers=HEADERS, verify=self.ssl_verify)
             returned = self.Result()(response.status_code, response.headers, response.json())
         except Exception as e:
             returned = self.Result()(500, {}, str(e))
@@ -181,7 +182,7 @@ class Iocs:
         FULL_URL = self.base_url+'/processes/entities/processes/v1?ids={}'.format(ID_LIST)
         HEADERS = self.headers
         try:
-            response = requests.request("GET", FULL_URL, headers=HEADERS, verify=False)
+            response = requests.request("GET", FULL_URL, headers=HEADERS, verify=self.ssl_verify)
             returned = self.Result()(response.status_code, response.headers, response.json())
         except Exception as e:
             returned = self.Result()(500, {}, str(e))
