@@ -40,12 +40,13 @@ class Real_Time_Response:
         is a valid token provided by the Falcon API SDK OAuth2 class.
     """
 
-    def __init__(self, access_token, base_url='https://api.crowdstrike.com'):
+    def __init__(self, access_token, base_url='https://api.crowdstrike.com', ssl_verify=True):
         """ Instantiates the base class, ingests the authorization token, 
             and initializes the headers and base_url global variables. 
         """
         self.headers = { 'Authorization': 'Bearer {}'.format(access_token) }
         self.base_url = base_url
+        self.ssl_verify = ssl_verify
 
     class Result:
         """ Subclass to handle parsing of result client output. """
@@ -68,7 +69,7 @@ class Real_Time_Response:
         HEADERS = self.headers
         DATA = body
         try:
-            response = requests.request("POST", FULL_URL, json=DATA, headers=HEADERS, verify=False)
+            response = requests.request("POST", FULL_URL, json=DATA, headers=HEADERS, verify=self.ssl_verify)
             returned = self.Result()(response.status_code, response.headers, response.json())
         except Exception as e:
             returned = self.Result()(500, {}, str(e))
@@ -83,7 +84,7 @@ class Real_Time_Response:
         DATA = body
         PARAMS = parameters
         try:
-            response = requests.request("POST", FULL_URL, params=PARAMS, json=DATA, headers=HEADERS, verify=False)
+            response = requests.request("POST", FULL_URL, params=PARAMS, json=DATA, headers=HEADERS, verify=self.ssl_verify)
             returned = self.Result()(response.status_code, response.headers, response.json())
         except Exception as e:
             returned = self.Result()(500, {}, str(e))
@@ -98,7 +99,7 @@ class Real_Time_Response:
         DATA = body
         PARAMS = parameters
         try:
-            response = requests.request("POST", FULL_URL, params=PARAMS, json=DATA, headers=HEADERS, verify=False)
+            response = requests.request("POST", FULL_URL, params=PARAMS, json=DATA, headers=HEADERS, verify=self.ssl_verify)
             returned = self.Result()(response.status_code, response.headers, response.json())
         except Exception as e:
             returned = self.Result()(500, {}, str(e))
@@ -112,7 +113,7 @@ class Real_Time_Response:
         HEADERS = self.headers
         PARAMS = parameters
         try:
-            response = requests.request("GET", FULL_URL, params=PARAMS, headers=HEADERS, verify=False)
+            response = requests.request("GET", FULL_URL, params=PARAMS, headers=HEADERS, verify=self.ssl_verify)
             returned = self.Result()(response.status_code, response.headers, response.json())
         except Exception as e:
             returned = self.Result()(500, {}, str(e))
@@ -129,7 +130,7 @@ class Real_Time_Response:
         DATA = body
         PARAMS = parameters
         try:
-            response = requests.request("POST", FULL_URL, params=PARAMS, json=DATA, headers=HEADERS, verify=False)
+            response = requests.request("POST", FULL_URL, params=PARAMS, json=DATA, headers=HEADERS, verify=self.ssl_verify)
             returned = self.Result()(response.status_code, response.headers, response.json())
         except Exception as e:
             returned = self.Result()(500, {}, str(e))
@@ -144,7 +145,7 @@ class Real_Time_Response:
         DATA = body
         PARAMS = parameters
         try:
-            response = requests.request("POST", FULL_URL, params=PARAMS, json=DATA, headers=HEADERS, verify=False)
+            response = requests.request("POST", FULL_URL, params=PARAMS, json=DATA, headers=HEADERS, verify=self.ssl_verify)
             returned = self.Result()(response.status_code, response.headers, response.json())
         except Exception as e:
             returned = self.Result()(500, {}, str(e))
@@ -159,7 +160,7 @@ class Real_Time_Response:
         DATA = body
         PARAMS = parameters
         try:
-            response = requests.request("POST", FULL_URL, params=PARAMS, json=DATA, headers=HEADERS, verify=False)
+            response = requests.request("POST", FULL_URL, params=PARAMS, json=DATA, headers=HEADERS, verify=self.ssl_verify)
             returned = self.Result()(response.status_code, response.headers, response.json())
         except Exception as e:
             returned = self.Result()(500, {}, str(e))
@@ -173,7 +174,7 @@ class Real_Time_Response:
         HEADERS = self.headers
         PARAMS = parameters
         try:
-            response = requests.request("GET", FULL_URL, params=PARAMS, headers=HEADERS, verify=False)
+            response = requests.request("GET", FULL_URL, params=PARAMS, headers=HEADERS, verify=self.ssl_verify)
             returned = self.Result()(response.status_code, response.headers, response.json())
         except Exception as e:
             returned = self.Result()(500, {}, str(e))
@@ -187,7 +188,7 @@ class Real_Time_Response:
         HEADERS = self.headers
         DATA = body
         try:
-            response = requests.request("POST", FULL_URL, json=DATA, headers=HEADERS, verify=False)
+            response = requests.request("POST", FULL_URL, json=DATA, headers=HEADERS, verify=self.ssl_verify)
             returned = self.Result()(response.status_code, response.headers, response.json())
         except Exception as e:
             returned = self.Result()(500, {}, str(e))
@@ -201,7 +202,7 @@ class Real_Time_Response:
         HEADERS = self.headers
         PARAMS = parameters
         try:
-            response = requests.request("GET", FULL_URL, params=PARAMS, headers=HEADERS, verify=False)
+            response = requests.request("GET", FULL_URL, params=PARAMS, headers=HEADERS, verify=self.ssl_verify)
             returned = self.Result()(response.status_code, response.headers, response.json())
         except Exception as e:
             returned = self.Result()(500, {}, str(e))
@@ -215,7 +216,7 @@ class Real_Time_Response:
         HEADERS = self.headers
         DATA = body
         try:
-            response = requests.request("POST", FULL_URL, json=DATA, headers=HEADERS, verify=False)
+            response = requests.request("POST", FULL_URL, json=DATA, headers=HEADERS, verify=self.ssl_verify)
             returned = self.Result()(response.status_code, response.headers, response.json())
         except Exception as e:
             returned = self.Result()(500, {}, str(e))
@@ -229,7 +230,7 @@ class Real_Time_Response:
         HEADERS = self.headers
         PARAMS = parameters
         try:
-            response = requests.request("GET", FULL_URL, params=PARAMS, headers=HEADERS, verify=False)
+            response = requests.request("GET", FULL_URL, params=PARAMS, headers=HEADERS, verify=self.ssl_verify)
             if response.headers.get('content-type') == "application/json":
                 returned = self.Result()(response.status_code, response.headers, response.json())
             else:
@@ -246,7 +247,7 @@ class Real_Time_Response:
         HEADERS = self.headers
         PARAMS = parameters
         try:
-            response = requests.request("GET", FULL_URL, params=PARAMS, headers=HEADERS, verify=False)
+            response = requests.request("GET", FULL_URL, params=PARAMS, headers=HEADERS, verify=self.ssl_verify)
             returned = self.Result()(response.status_code, response.headers, response.json())
         except Exception as e:
             returned = self.Result()(500, {}, str(e))
@@ -261,7 +262,7 @@ class Real_Time_Response:
         HEADERS = self.headers
         PARAMS = parameters
         try:
-            response = requests.request("DELETE", FULL_URL, params=PARAMS, headers=HEADERS, verify=False)
+            response = requests.request("DELETE", FULL_URL, params=PARAMS, headers=HEADERS, verify=self.ssl_verify)
             returned = self.Result()(response.status_code, response.headers, response.json())
         except Exception as e:
             returned = self.Result()(500, {}, str(e))
@@ -275,7 +276,7 @@ class Real_Time_Response:
         HEADERS = self.headers
         DATA = body
         try:
-            response = requests.request("POST", FULL_URL, json=DATA, headers=HEADERS, verify=False)
+            response = requests.request("POST", FULL_URL, json=DATA, headers=HEADERS, verify=self.ssl_verify)
             returned = self.Result()(response.status_code, response.headers, response.json())
         except Exception as e:
             returned = self.Result()(500, {}, str(e))
@@ -289,7 +290,7 @@ class Real_Time_Response:
         HEADERS = self.headers
         DATA = body
         try:
-            response = requests.request("POST", FULL_URL, json=DATA, headers=HEADERS, verify=False)
+            response = requests.request("POST", FULL_URL, json=DATA, headers=HEADERS, verify=self.ssl_verify)
             returned = self.Result()(response.status_code, response.headers, response.json())
         except Exception as e:
             returned = self.Result()(500, {}, str(e))
@@ -303,7 +304,7 @@ class Real_Time_Response:
         HEADERS = self.headers
         DATA = body
         try:
-            response = requests.request("POST", FULL_URL, json=DATA, headers=HEADERS, verify=False)
+            response = requests.request("POST", FULL_URL, json=DATA, headers=HEADERS, verify=self.ssl_verify)
             returned = self.Result()(response.status_code, response.headers, response.json())
         except Exception as e:
             returned = self.Result()(500, {}, str(e))
@@ -317,7 +318,7 @@ class Real_Time_Response:
         HEADERS = self.headers
         DATA = body
         try:
-            response = requests.request("POST", FULL_URL, json=DATA, headers=HEADERS, verify=False)
+            response = requests.request("POST", FULL_URL, json=DATA, headers=HEADERS, verify=self.ssl_verify)
             returned = self.Result()(response.status_code, response.headers, response.json())
         except Exception as e:
             returned = self.Result()(500, {}, str(e))
@@ -331,7 +332,7 @@ class Real_Time_Response:
         HEADERS = self.headers
         PARAMS = parameters
         try:
-            response = requests.request("DELETE", FULL_URL, params=PARAMS, headers=HEADERS, verify=False)
+            response = requests.request("DELETE", FULL_URL, params=PARAMS, headers=HEADERS, verify=self.ssl_verify)
             returned = self.Result()(response.status_code, response.headers, response.json())
         except Exception as e:
             returned = self.Result()(500, {}, str(e))
@@ -345,7 +346,7 @@ class Real_Time_Response:
         HEADERS = self.headers
         PARAMS = parameters
         try:
-            response = requests.request("DELETE", FULL_URL, params=PARAMS, headers=HEADERS, verify=False)
+            response = requests.request("DELETE", FULL_URL, params=PARAMS, headers=HEADERS, verify=self.ssl_verify)
             returned = self.Result()(response.status_code, response.headers, response.json())
         except Exception as e:
             returned = self.Result()(500, {}, str(e))
@@ -359,7 +360,7 @@ class Real_Time_Response:
         HEADERS = self.headers
         PARAMS = parameters
         try:
-            response = requests.request("GET", FULL_URL, params=PARAMS, headers=HEADERS, verify=False)
+            response = requests.request("GET", FULL_URL, params=PARAMS, headers=HEADERS, verify=self.ssl_verify)
             returned = self.Result()(response.status_code, response.headers, response.json())
         except Exception as e:
             returned = self.Result()(500, {}, str(e))
